@@ -27,6 +27,7 @@ import pygtk
 import gtk
 import gtk.gdk
 import gobject
+import pango
 import weakref
 
 from ccm.Constants import *
@@ -57,6 +58,9 @@ def getScreens():
         screens.append(i)
     return screens
 
+def protect_markup_dict (dict_):
+    return dict((k, protect_pango_markup (v)) for (k, v) in dict_.iteritems())
+
 class Image (gtk.Image):
 
     def __init__ (self, name = None, type = ImageNone, size = 32):
@@ -185,7 +189,7 @@ class Label(gtk.Label):
     def __init__(self, value = "", wrap = 160):
         gtk.Label.__init__(self, value)
         self.props.xalign = 0
-        self.props.wrap_mode = gtk.WRAP_WORD
+        self.props.wrap_mode = pango.WRAP_WORD
         self.set_line_wrap(True)
         self.set_size_request(wrap, -1)
 
@@ -209,11 +213,12 @@ class NotFoundBox(gtk.Alignment):
         self.Warning.set_markup(self.Markup % value)
 
 class IdleSettingsParser:
-    def __init__(self, context):
+    def __init__(self, context, main):
         def FilterPlugin (p):
             return not p.Initialized and p.Enabled
 
         self.Context = context
+        self.Main = main
         self.PluginList = [p for p in self.Context.Plugins.items() if FilterPlugin(p[1])]
         
         gobject.timeout_add (200, self.Wait)
@@ -231,6 +236,7 @@ class IdleSettingsParser:
 
         if not plugin.Initialized:
             plugin.Update ()
+            self.Main.RefreshPage(plugin)
 
         self.PluginList.remove (self.PluginList[0])
 
@@ -335,6 +341,9 @@ def CategoryKeyFunc(category):
     else:
         return category or 'zzzzzzzz'
 
+def GroupIndexKeyFunc(item):
+    return item[1][0]
+
 FirstItemKeyFunc = operator.itemgetter(0)
 
 EnumSettingKeyFunc = operator.itemgetter(1)
